Plot residuals obtained by a joint model (obtained by joint).
If the residuals.joint object represents the longitudinal process, a simple (panelled)
plot is produced (one for each response). If the residual object contains the Cox-Snell
resdiuals then a 1x2 panel is produced with the KM estimate of survival function of these
residuals in the left-hand plot, and the same estimate mimicing the survival formula used in
the original call to joint.
# S3 method for residuals.joint
plot(x, ...)an object with class residuals.joint.
additional arguments (none used).
James Murray (j.murray7@ncl.ac.uk).
residuals.joint