Learn R Programming

gmvjoint (version 0.4.0)

rgenpois: Simulate realisations from a generalised poisson distribution

Description

Simulate realisations from a generalised poisson distribution

Usage

rgenpois(mu, phi)

Value

An appropriately-dimensioned vector of count data.

Arguments

mu

A numeric vector of rates \(\exp{\eta}\), with \(\eta\) the linear predictor.

phi

A numeric specifying the dispersion \(\varphi\). If \(\varphi<0\) the response will be under-dispersed and overdispersed if \(\varphi>0\).

Details

Follows the "GP-1" implementation of the generalised Poisson distribution outlined in Zamani & Ismail (2012). The variance of produced \(Y\) is \((1+\varphi)^2\mu\). As such the dispersion parameter is bounded (i.e. not in positive reals as with CMP distribution).

References

Zamani H and Ismail N. Functional Form for the Generalized Poisson Regression Model, Communications in Statistics - Theory and Methods 2012; 41(20); 3666-3675.