Calculate the log-likelihood of a joint model of survival and multivariate longitudinal
data (i.e. a joint object). The argument conditional manages whether
or not the log-likelihood conditional on the random effects, or simply
the observed data log-likelihood is returned (the default, conditional = FALSE).
If conditional = TRUE, then the log-likelihood conditional on the random
effects is returned. That is
$$\log f(T_i, \Delta_i, Y_i|b_i;\Omega) =
\log f(Y_i|b_i; \Omega) + \log f(T_i, \Delta_i|b_i; \Omega) + \log f(b_i|\Omega)$$
If conditional = FALSE, then the observed data log-likelihood is returned i.e.
$$\log\int f(Y_i|b_i; \Omega)f(T_i, \Delta_i|b_i; \Omega)f(b_i|\Omega)db_i.$$
Additionally, the degrees of freedom, \(\nu\) is given by
$$\nu = \code{length(vech(D))} + \sum_{k=1}^K\{P_k + P_{\sigma_k}\} + P_s,$$
where \(P_k\) denotes the number of coefficients estimated for the \(k\)th response,
and \(P_{\sigma_k}\) the number of dispersion parameters estimated. \(P_s\) denotes
the number of survival coefficients, i.e. the length of c(zeta, gamma). Finally,
all covariance parameters are captured in length(vech(D)).
With the degrees of freedom, we can additionally compute AIC and BIC, which are defined
in no special way; and are calculated using the observed data log-likelihood.