Simulate realisations from a generalised poisson distribution
rgenpois(mu, phi)An appropriately-dimensioned vector of count data.
A numeric vector of rates \(\exp{\eta}\), with \(\eta\) the linear predictor.
A numeric specifying the dispersion \(\varphi\). If \(\varphi<0\) the response will be under-dispersed and overdispersed if \(\varphi>0\).
Follows the "GP-1" implementation of the generalised Poisson distribution outlined in Zamani & Ismail (2012). The variance of produced \(Y\) is \((1+\varphi)^2\mu\). As such the dispersion parameter is bounded (i.e. not in positive reals as with CMP distribution).
Zamani H and Ismail N. Functional Form for the Generalized Poisson Regression Model, Communications in Statistics - Theory and Methods 2012; 41(20); 3666-3675.